@@ -22,28 +22,23 @@
 
 #include "config.h"
 
+#include "eggsmclient.h"
+#include "ephy-debug.h"
+#include "ephy-file-helpers.h"
+#include "ephy-session.h"
 #include "ephy-settings.h"
 #include "ephy-shell.h"
-#include "ephy-file-helpers.h"
 #include "ephy-state.h"
-#include "ephy-debug.h"
 #include "ephy-stock-icons.h"
-#include "ephy-session.h"
-#include "ephy-shell.h"
-#include "ephy-web-app-utils.h"
-#include "ephy-debug.h"
 #include "ephy-string.h"
-#include "eggsmclient.h"
-
-#include <libxml/xmlversion.h>
-#include <libnotify/notify.h>
-
-#include <glib/gi18n.h>
-
-#include <gdk/gdkx.h>
-#include <gtk/gtk.h>
+#include "ephy-web-app-utils.h"
 
 #include <errno.h>
+#include <gdk/gdkx.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+#include <libnotify/notify.h>
+#include <libxml/xmlversion.h>
 #include <string.h>
 
 #ifdef ENABLE_INTROSPECTION
@@ -258,9 +253,6 @@ main (int argc,
   textdomain (GETTEXT_PACKAGE);
 #endif
 
-  /* Threads have to be initialised before calling ANY glib function */
-  g_thread_init (NULL);
-
   /* check libxml2 API version epiphany was compiled with against the
    * version we're running with.
    */
@@ -388,6 +380,18 @@ main (int argc,
     exit (1);
   }
 
+  /* Work-around Flash Player crash */
+  g_setenv ("XLIB_SKIP_ARGB_VISUALS", "1", FALSE);
+
+  /* Start our services */
+  if (!ephy_file_helpers_init (profile_directory,
+                               private_instance || application_mode,
+                               keep_temp_directory || profile_directory,
+                               &error)) {
+    show_error_message (&error);
+    exit (1);
+  }
+
   arbitrary_url = g_settings_get_boolean (EPHY_SETTINGS_LOCKDOWN,
                                           EPHY_PREFS_LOCKDOWN_ARBITRARY_URL);
 
@@ -416,15 +420,6 @@ main (int argc,
 
   startup_error_quark = g_quark_from_static_string ("epiphany-startup-error");
 
-  /* Start our services */
-  if (!ephy_file_helpers_init (profile_directory,
-                               private_instance || application_mode,
-                               keep_temp_directory || profile_directory,
-                               &error)) {
-    show_error_message (&error);
-    exit (1);
-  }
-
   /* Delete the requested web application, if any. Must happen after
    * ephy_file_helpers_init (). */
   if (application_to_delete) {
@@ -435,9 +430,6 @@ main (int argc,
   ephy_stock_icons_init ();
   ephy_file_load_accels ();
 
-  /* Work-around Flash Player crash */
-  g_setenv ("XLIB_SKIP_ARGB_VISUALS", "1", FALSE);
-
   /* Now create the shell */
   if (private_instance)
     mode = EPHY_EMBED_SHELL_MODE_PRIVATE;
