@@ -45,7 +45,7 @@ typedef struct _EphyWindowPrivate	EphyWindowPrivate;
 
 struct _EphyWindow
 {
-	GtkWindow parent;
+	GtkApplicationWindow parent;
 
 	/*< private >*/
 	EphyWindowPrivate *priv;
@@ -53,7 +53,7 @@ struct _EphyWindow
 
 struct _EphyWindowClass
 {
-	GtkWindowClass parent_class;
+	GtkApplicationWindowClass parent_class;
 };
 
 GType		  ephy_window_get_type		  (void);
@@ -85,6 +85,8 @@ EphyEmbedEvent	 *ephy_window_get_context_event	  (EphyWindow *window);
 void		  ephy_window_set_downloads_box_visibility (EphyWindow *window,
 							    gboolean show);
 
+GtkActionGroup   *ephy_window_get_toolbar_action_group (EphyWindow *window);
+
 G_END_DECLS
 
 #endif
